@@ -14,13 +14,18 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 
 #include "msopenh264dec.h"
 #include "mediastreamer2/msticker.h"
 #include "ortp/b64.h"
+#include "wels/codec_ver.h"
+
+static void decoder_log(void* context, int level, const char* message){
+	ms_message("OpenH264 decoder: %s", message);
+}
 
 MSOpenH264Decoder::MSOpenH264Decoder(MSFilter *f)
 	: mFilter(f), mDecoder(0), mUnpacker(0), mSPS(0), mPPS(0), mYUVMsg(0),
@@ -33,6 +38,10 @@ MSOpenH264Decoder::MSOpenH264Decoder(MSFilter *f)
 		ms_error("OpenH264 decoder: Failed to create decoder: %li", ret);
 	} else {
 		mBitstream = static_cast<uint8_t *>(ms_malloc0(mBitstreamSize));
+		WelsTraceCallback cb = &decoder_log;
+		mDecoder->SetOption(DECODER_OPTION_TRACE_CALLBACK, (void*)&cb);
+		int logLevel = WELS_LOG_WARNING;
+		mDecoder->SetOption(DECODER_OPTION_TRACE_LEVEL, &logLevel);
 	}
 }
 
@@ -53,11 +62,14 @@ void MSOpenH264Decoder::initialize()
 		mUnpacker=rfc3984_new();
 		if (mDecoder != 0) {
 			SDecodingParam params = { 0 };
+#if (OPENH264_MAJOR == 1) && (OPENH264_MINOR >=6)
+#else
 			params.eOutputColorFormat = videoFormatI420;
+#endif
 			params.uiTargetDqLayer = (unsigned char) -1;
 			params.eEcActiveIdc = ERROR_CON_FRAME_COPY_CROSS_IDR;
 			params.sVideoProperty.size = sizeof(params.sVideoProperty);
-			params.sVideoProperty.eVideoBsType = VIDEO_BITSTREAM_DEFAULT;
+			params.sVideoProperty.eVideoBsType = VIDEO_BITSTREAM_AVC;
 			long ret = mDecoder->Initialize(&params);
 			if (ret != 0) {
 				ms_error("OpenH264 decoder: Failed to initialize: %li", ret);
@@ -97,10 +109,10 @@ void MSOpenH264Decoder::feed()
 			void * pData[3] = { 0 };
 			SBufferInfo sDstBufInfo = { 0 };
 			int len = nalusToFrame(&nalus);
-
+			
 			DECODING_STATE state = mDecoder->DecodeFrame2(mBitstream, len, (uint8_t**)pData, &sDstBufInfo);
 			if (state != dsErrorFree) {
-				ms_error("OpenH264 decoder: DecodeFrame2 failed: 0x%x", state);
+				ms_error("OpenH264 decoder: DecodeFrame2 failed: 0x%x", (int)state);
 				if (mAVPFEnabled) {
 					requestPLI = true;
 				} else if (((mFilter->ticker->time - mLastErrorReportTime) > 5000) || (mLastErrorReportTime == 0)) {
